	SUBROUTINE geolocate_ssmis(Tb, lat, lon, aline, out_lat, out_lon)
C	
C	Subroutine to interpolate SSMI environmental channels to common grid
C 	common grid is that of the imager channels (91V and 91H)
C
C 	Environmental channels: 19H, 19V, 22V, 37H, 37V
C
C	   91H, 91V = Tb([6 7])  [lat/lon index 1] not interpolated
C	   19H, 19V, 22V = Tb([1 2 3])  [lat/lon index 3]
C	   37H, 37V = Tb([4 5])  [lat/lon index 2]
C	
C	Nearest neighbor approach is used
C
C	Written by D. A. Vila; Set 2011
C       Modifications: 12/21/2011 EJN  Account for longitudes straddling
C                                      dateline
C

      	implicit none
	include	'parameters.inc'


	!==== input parameters =================================================
	integer*4 	aline			!total # of scan lines in this file
	real*4 		lat(NPIX,MAX_SCANS,3)
	real*4		lon(NPIX,MAX_SCANS,3)
		
	
	! ==== helper variables ================================================
	integer*4 	i1, i2, i3, j1, j2, nscans
	integer*4       j1_st, j1_en, j2_st, j2_en
	integer*2       ii,jj
	real*4		d1, d2, mindist2, mindist3, xlon

	real*4    	w1(NPIX,MAX_SCANS), w2(NPIX,MAX_SCANS)
	real*4		Tb_adj(NPIX,MAX_SCANS,NCHAN)

	
	!===== output parameters.===============================================
	real*4 		out_lat(NPIX,MAX_SCANS)
	real*4		out_lon(NPIX,MAX_SCANS)


	!===== input/output parameters.===============================================
	real*4		Tb(NPIX,MAX_SCANS,NCHAN)

	!!!----------------------------------------------!!!
	! Set up the output variables
	do j1=1, NPIX
	  do j2=1, MAX_SCANS

	    out_lat(j1,j2)=lat(j1,j2,1)
	    out_lon(j1,j2)=lon(j1,j2,1)

	    do i1=1, 5
	      TB_adj(j1,j2,i1)=MISS_FLT
	    enddo

	    TB_adj(j1,j2,6)=TB(j1,j2,6)
	    TB_adj(j1,j2,7)=TB(j1,j2,7)

	  enddo
	enddo


	!!!----------------------------------------------!!!
	! Loop over all pixels and scanlines
	do i1=1, NPIX
	  do i2=1, aline


  	     !!!---------------------------------------!!!
	     ! calculate search area: look in nearest neighbor (east and west)

	     j1_st=i1-1
	     if (j1_st .lt. 1) then
		j1_st=1
	     endif

	     j1_en=i1+1
	     if (j1_en .gt. (NPIX)) then
		j1_en=NPIX
	     endif

	     j2_st=i2-1
	     if (j2_st .lt. 1) then
		j2_st=1
	     endif

	     j2_en=i2+1
	     if (j2_en .gt. (aline)) then
		j2_en=aline
	     endif


	    !!!----------------------------------------------!!!
	    ! calculate min distance
	    
	    mindist3=999
	    mindist2=999
	    do j1=j1_st, j1_en
	      do j2=j2_st, j2_en
                 
		! weights for 19H, 19V, 22V
	        d1=out_lat(i1,i2)-lat(j1,j2,3)
C
C EJN - Account for longitudes straddling the dateline.
C
                if (out_lon(i1,i2) .LT. -179. .AND.
     +              lon(j1,j2,3) .GT. 179.) then
                      xlon = lon(j1,j2,3) - 360.
                      d2 = out_lon(i1,i2) - xlon
                else if ( lon(j1,j2,3) .LT.-179. .AND.
     +                    out_lon(i1,i2) .GT. 179.) then
                      xlon = out_lon(i1,i2) - 360.
                      d2 = xlon - lon(j1,j2,3)
                else
                      d2 = out_lon(i1,i2) - lon(j1,j2,3)
                endif
C
CEJN	        d2=out_lon(i1,i2)-lon(j1,j2,3)
	        w1(j1,j2)=sqrt((d1*d1)+(d2*d2))
		if (w1(j1,j2).le.mindist3) then
		mindist3= w1(j1,j2)
		   do i3 = 1, 3
		     TB_adj(i1,i2,i3)=TB(j1,j2,i3)
                   enddo
		endif
		

		! weights for 37H, 37V
	        d1=out_lat(i1,i2)-lat(j1,j2,2)
C
C EJN - Account for longitudes straddling the dateline.
C
                if (out_lon(i1,i2) .LT. -179. .AND.
     +              lon(j1,j2,2) .GT. 179.) then
                      xlon = lon(j1,j2,2) - 360.
                      d2 = out_lon(i1,i2) - xlon
                else if ( lon(j1,j2,2) .LT.-179. .AND.
     +                    out_lon(i1,i2) .GT. 179.) then
                      xlon = out_lon(i1,i2) - 360.
                      d2 = xlon - lon(j1,j2,2)
                else
                      d2 = out_lon(i1,i2) - lon(j1,j2,2)
                endif
CEJN	        d2=out_lon(i1,i2)-lon(j1,j2,2)
	        w2(j1,j2)=sqrt((d1*d1)+(d2*d2))
		if (w2(j1,j2).le.mindist2) then
		mindist2= w2(j1,j2)
		   do i3 = 4, 5
		     TB_adj(i1,i2,i3)=TB(j1,j2,i3)
                   enddo
		endif

	      enddo
	    enddo



	  enddo
	enddo






	!!!----------------------------------------------!!!
	! Swap output variables
	do j1=1, NPIX
	  do j2=1, MAX_SCANS
	    do i1=1, NCHAN

	      TB(j1,j2,i1)=TB_adj(j1,j2,i1)

	    enddo
	  enddo
	enddo
	
	return

	end



